@@ -34,6 +34,7 @@
 #include <errno.h>
 #include <sys/ioctl.h>
 #include <ctype.h>
+#include <stdint.h>
 #include <linux/fs.h>
 
 #include <linux/hdreg.h>
@@ -1410,7 +1411,7 @@ part_add_change_partition (char *device_file,
       DEBUG ("In part_add_partition: device_file=%s, start=%lld, size=%lld, type=%s", device_file, start, size, type);
     }
 
-  scheme = -1;
+  scheme = PART_TYPE_UNKNOWN;
   if (is_change)
     {
       PartitionTable *p;
@@ -1456,7 +1457,7 @@ part_add_change_partition (char *device_file,
   /* now that we know the partitoning scheme, sanity check type and flags */
   switch (scheme)
     {
-    case -1:
+    case PART_TYPE_UNKNOWN:
       /* unknown partition table format; error out if any type, label or flags are given */
       if ((flags != NULL && flags[0] != NULL))
         {
